summaryrefslogtreecommitdiffstats
path: root/registry/inc
diff options
context:
space:
mode:
authorOliver Bolte <obo@openoffice.org>2009-02-12 09:18:09 +0000
committerOliver Bolte <obo@openoffice.org>2009-02-12 09:18:09 +0000
commite591a08dc3d37e13703c855a7f4056faa4e34406 (patch)
treeb68b0ea9d11b8450db6dbcf1040a12c918a44f1a /registry/inc
parent#i10000# missing changes from jl111 (diff)
downloadcore-e591a08dc3d37e13703c855a7f4056faa4e34406.tar.gz
core-e591a08dc3d37e13703c855a7f4056faa4e34406.zip
CWS-TOOLING: integrate CWS sb103
2009-01-15 15:28:08 +0100 sb r266375 : #i97629# set UNO_PATH in python start program and use it in bootstrap function in officehelper.py (and do not erroneously encode a vnd.sun.star.pathname URE_BOOTSTRAP value in tools::extendApplicationEnvironment) 2009-01-15 10:40:17 +0100 sb r266338 : #i97424# explicit shut down of ImplImageTree singleton in DeInitVCL still required 2009-01-14 12:07:15 +0100 sb r266276 : CWS-TOOLING: rebase CWS sb103 to trunk@265758 (milestone: DEV300:m38) 2009-01-14 08:53:02 +0100 sb r266266 : #i96284# remove implementation of unused (but expensive) link feature; plus some general cleanup 2009-01-08 14:42:59 +0100 sb r266010 : #i96683# enable dlclose for GCC 3 (based on a patch by cmc) 2009-01-06 14:18:23 +0100 sb r265920 : #i97424# spurious unreferenced local variables 2008-12-19 15:33:39 +0100 sb r265727 : #i57359# no need for a special glibc 2.2.4 based libgcc_s.so.1 for URE any more as the general one used for OOo is guaranteed to be based on at least glibc 2.2.4, anyway 2008-12-19 13:54:37 +0100 sb r265724 : #i97424# clean up and speed up vcl ImplImageTree 2008-12-18 14:28:10 +0100 sb r265690 : #i97132# spread usage of the rtl::Static pattern (patch by cmc) 2008-12-15 14:33:00 +0100 sb r265499 : #i90492# generate UTF-8 encoded output (patch by tora) 2008-12-15 11:45:05 +0100 sb r265469 : #i95593# -Djava.library.path to find libtest_javauno_any.so 2008-12-15 11:23:14 +0100 sb r265468 : #i93769# it appears that Java nowadays expects file URIs in UTF-8, so ExternalUriReferenceTranslator.toExternal must not be called 2008-12-10 12:02:50 +0100 sb r265164 : #i93219# use (corrected) signal handling instead of forking again (to avoid unintended generation of core files)
Diffstat (limited to 'registry/inc')
-rw-r--r--registry/inc/registry/registry.h42
-rw-r--r--registry/inc/registry/registry.hxx34
-rw-r--r--registry/inc/registry/regtype.h18
3 files changed, 45 insertions, 49 deletions
diff --git a/registry/inc/registry/registry.h b/registry/inc/registry/registry.h
index 294aaa0b3cad..99b314b5767c 100644
--- a/registry/inc/registry/registry.h
+++ b/registry/inc/registry/registry.h
@@ -281,29 +281,21 @@ RegError REGISTRY_CALLTYPE reg_freeValueList(RegValueType valueType,
RegValue pValueList,
sal_uInt32 len);
-/** This function creates a link with the specified link name and link target.
+/** This function used to create a link.
- Links in the registry are similar to links in the UNIX fielsystem. If a link will be opened,
- the link target will be resolved and the key speciefied by the link target will be opened.
- @param hKey identifies a currently open key. The link which will be created is a subkey
- of the key identified by hKey.
- @param linkName points to a null terminated string specifying the name of the new link.
- @param linkTarget points to a null terminated string specifying the link target of the new link.
- The linktarget must specify a valid name of an existing key. The linktarget itself
- can contain links in the full qualified name. All links will be resolved if the
- link will be opened.
- @return REG_NO_ERROR if succeeds else an error code.
+ @obsolete Links are no longer supported.
+
+ @return REG_INVALID_LINK
*/
RegError REGISTRY_CALLTYPE reg_createLink(RegKeyHandle hKey,
rtl_uString* linkName,
rtl_uString* linkTarget);
-/** This function deletes a link with the specified linkname.
+/** This function used to delete a link.
- @param hKey identifies a currently open key. The link which will be deleted is a subkey
- of the key identified by hKey.
- @param linkName points to a null terminated string specifying the name of the link.
- @return REG_NO_ERROR if succeeds else an error code.
+ @obsolete Links are no longer supported.
+
+ @return REG_INVALID_LINK
*/
RegError REGISTRY_CALLTYPE reg_deleteLink(RegKeyHandle hKey,
rtl_uString* linkName);
@@ -312,7 +304,7 @@ RegError REGISTRY_CALLTYPE reg_deleteLink(RegKeyHandle hKey,
The registry differentiates two possible types:
- RG_KEYTYPE represents a real key
- - RG_LINKTYPE represents a link
+ - RG_LINKTYPE used to represent a link (no longer used)
@param keyName points to a null terminated string specifying the name of the key which keytype
will be returned.
@param pKeyType returns the type of the key.
@@ -322,24 +314,24 @@ RegError REGISTRY_CALLTYPE reg_getKeyType(RegKeyHandle hKey,
rtl_uString* keyName,
RegKeyType* pKeyType);
-/** This function returns the linktarget of a link.
+/** This function used to return the linktarget of a link.
- @param linkName points to a null terminated string specifying the name of the link which
- linktarget will be returned.
- @param pLinkTarget contains the linktarget if succeeds else an empty string.
- @return REG_NO_ERROR if succeeds else an error code.
+ @obsolete Links are no longer supported.
+
+ @return REG_INVALID_LINK
*/
RegError REGISTRY_CALLTYPE reg_getLinkTarget(RegKeyHandle hKey,
rtl_uString* linkName,
rtl_uString** pLinkTarget);
-/** This function resolves all or only the first link of a keyname.
+/** This function resolves a keyname.
and returns the resolved keyName in pResolvedName.
@param hKey identifies a currently open key. The key specified by keyName is a subkey
of the key identified by hKey.
@param keyName points to a null terminated string specifying the relativ name of a key.
- The name of hKey together with keyName will be resolved from links.
+ The name of hKey together with keyName will be generated.
+ @param firstLinkOnly ignored
@return REG_NO_ERROR if succeeds else an error code.
*/
RegError REGISTRY_CALLTYPE reg_getResolvedKeyName(RegKeyHandle hKey,
@@ -473,7 +465,7 @@ RegError REGISTRY_CALLTYPE reg_destroyRegistry(RegHandle hRegistry,
/** This function reports the complete registry information of a key and all of its subkeys.
- All information which are available (keynames, value types, values, linknames, linktargets, ...)
+ All information which are available (keynames, value types, values, ...)
will be printed to stdout for report issues only.
@param hKey identifies a currently open key which content will be reported.
@return REG_NO_ERROR if succeeds else an error code.
diff --git a/registry/inc/registry/registry.hxx b/registry/inc/registry/registry.hxx
index c1c4d106fc8f..e3ee4574023d 100644
--- a/registry/inc/registry/registry.hxx
+++ b/registry/inc/registry/registry.hxx
@@ -219,7 +219,7 @@ public:
/** This function reports the complete registry information of a key and all of its subkeys.
- All information which are available (keynames, value types, values, linknames, linktargets, ...)
+ All information which are available (keynames, value types, values, ...)
will be printed to stdout for report issues only.
@param rKey references a currently open key which content will be reported.
@return REG_NO_ERROR if succeeds else an error code.
@@ -597,46 +597,46 @@ public:
inline RegError getUnicodeListValue(const ::rtl::OUString& keyName,
RegistryValueList<sal_Unicode*>& rValueList);
- /** creates a new link with the specified name and target.
+ /** used to create a link.
- @param linkName specifies the name of link
- @param linkTarget specifies a full qualified keyname as target for the link.
- @return REG_NO_ERROR if succeeds else an error code.
+ @obsolete Links are no longer supported.
+
+ @return REG_INVALID_LINK
*/
inline RegError createLink(const ::rtl::OUString& linkName,
const ::rtl::OUString& linkTarget);
- /** deletes an existing link.
+ /** used to delete a link.
- @param linkName specifies the name of link
- @return REG_NO_ERROR if succeeds else an error code.
+ @obsolete Links are no longer supported.
+
+ @return REG_INVALID_LINK
*/
inline RegError deleteLink(const ::rtl::OUString& linkName);
- /** returns the type of the specified key if it is a link or a real key.
+ /** returns the type of the specified key.
@param name specifies the name of the key or link.
- @param pKeyType returns the type of the key.
+ @param pKeyType returns the type of the key (always RG_KEYTYPE).
@return REG_NO_ERROR if succeeds else an error code.
*/
inline RegError getKeyType(const ::rtl::OUString& name,
RegKeyType* pKeyType) const;
- /** returns the target of the specified link.
+ /** used to return the target of a link.
- @param linkName specifies the name of link.
- @param rLinkTarget returns the target keyname of the link.
- @return REG_NO_ERROR if succeeds else an error code.
+ @obsolete Links are no longer supported.
+
+ @return REG_INVALID_LINK
*/
inline RegError getLinkTarget(const ::rtl::OUString& linkName,
::rtl::OUString& rLinkTarget) const;
- /** resolves all or only the first link of a keyname.
+ /** resolves a keyname.
- The function resolves either only the first link or it resolves all links
- which exists in the keyname or recursive in the resolved parts.
@param keyName specifies the name of the key which will be resolved relativ to this key.
The resolved name will be prefixed with the name of this key.
+ @param firstLinkOnly ignored
@return REG_NO_ERROR if succeeds else an error code.
*/
inline RegError getResolvedKeyName(const ::rtl::OUString& keyName,
diff --git a/registry/inc/registry/regtype.h b/registry/inc/registry/regtype.h
index 7e4ec33adab4..7e22f0cd4d12 100644
--- a/registry/inc/registry/regtype.h
+++ b/registry/inc/registry/regtype.h
@@ -64,13 +64,13 @@ typedef sal_uInt16 RegAccessMode;
The registry differs between normal keys which can contain subkeys or
a value and link keys which navigate over the linktarget to an existing
- other key. The mechanism is similar to links in a UNIX filesystem.
+ other key (which are no longer supported).
*/
enum RegKeyType
{
/// represents a real key
RG_KEYTYPE,
- /// represents a link
+ /// represents a link (which is no longer supported)
RG_LINKTYPE
};
@@ -158,15 +158,19 @@ enum RegError
*/
REG_MERGE_CONFLICT,
- /// a recursion was detected resolving different link targets.
+ /** a recursion was detected resolving different link targets (no longer
+ used).
+ */
REG_DETECT_RECURSION,
- /// the link is invalid and can not be resolved.
+ /** the link is invalid and can not be resolved (now used by all
+ link-related operations, as links are no longer supported).
+ */
REG_INVALID_LINK,
/// the specified linkname is not valid.
REG_INVALID_LINKNAME,
/// the linknane is not valid.
REG_INVALID_LINKTARGET,
/// the link target points to a nonexisting key.
REG_LINKTARGET_NOT_EXIST,
/// the reserved buffer for the resolved keyname is to small.
REG_BUFFERSIZE_TOSMALL
@@ -158,15 +158,19 @@ enum RegError
REG_INVALID_LINK,
- /// the specified linkname is not valid.
+ /// the specified linkname is not valid (no longer used).
REG_INVALID_LINKNAME,
@@ -158,15 +158,19 @@ enum RegError
REG_INVALID_LINKNAME,
- /// the linknane is not valid.
+ /// the linknane is not valid (no longer used).
REG_INVALID_LINKTARGET,
@@ -158,15 +158,19 @@ enum RegError
REG_INVALID_LINKTARGET,
- /// the link target points to a nonexisting key.
+ /// the link target points to a nonexisting key (no longer used).
REG_LINKTARGET_NOT_EXIST,
/// the reserved buffer for the resolved keyname is to small.